package com.esignlive.guidance.forum;

import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignerBuilder.newSignerWithEmail;

import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.ExtractionType;
import com.silanis.esl.sdk.FieldCondition;
import com.silanis.esl.sdk.FieldId;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.ReferencedConditions;
import com.silanis.esl.sdk.SignatureId;
import com.silanis.esl.sdk.builder.DocumentBuilder;
import com.silanis.esl.sdk.builder.FieldBuilder;
import com.silanis.esl.sdk.builder.FieldConditionBuilder;
import com.silanis.esl.sdk.builder.PackageBuilder;
import com.silanis.esl.sdk.builder.SignatureBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;


public class _20_06_15_conditional_fields_troubleshoot {	
	
    private static final String DOCUMENT_ID_1 = "3";
    private final static SignatureId signatureId1 = new SignatureId("signatureId1");
    private final static FieldId fieldId1 = new FieldId("radio1");
    private final static FieldId fieldId2 = new FieldId("nhStreet");
    
    //change below fields
	public static final String API_KEY = "your_api_key";
	public static final String API_URL = "https://sandbox.esignlive.com/api";
	public static final String email = "signer1@mailinator.com";
	public static final String filePath = "your_file_path";

	
	public static void main(String[] args) {
		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		
		FieldCondition conditionRadio1 = FieldConditionBuilder.newFieldCondition()
                .withId("condition1")
                .withCondition("document['3'].field['radio1'].value == '' ") //note:  the font does not show it well but this is two single ticks followed by a quotation mark
                .withAction("document['3'].field['nhStreet'].disabled = true")
                .build();
        FieldCondition conditionRadio2 = FieldConditionBuilder.newFieldCondition()
                .withId("condition2")
                .withCondition("document['3'].field['radio1'].value == 'X'")
                .withAction("document['3'].field['nhStreet'].disabled = false")
                .build();
        FieldCondition conditionRadio3 = FieldConditionBuilder.newFieldCondition()
                .withId("condition3")
                .withCondition("document['3'].field['radio1'].value == 'X'")
                .withAction("document['3'].field['nhStreet'].required = true")
                .build();
		
		
		 DocumentPackage superDuperPackage = newPackageNamed("Test Package with conditinal field")
		            .describedAs("This is a package created using the eSignLive SDK")
		            .withEmailMessage("This message should be delivered to all signers")
		            .withSigner(newSignerWithEmail(email)
		                .withCustomId("Signer1")
		                .withFirstName("firstName1")
		                .withLastName("lastName1"))
		            .withDocument(newDocumentWithName("PackageReferencedConditionsExampleDocument1")
	                    .fromFile(filePath)
		                .withId(DOCUMENT_ID_1)
		                .withSignature(SignatureBuilder.signatureFor(email)
		                    .onPage(0)
		                    .atPosition(100, 100)
		                    .withId(signatureId1)
		                    .withField(FieldBuilder.radioButton("defaultGroup")
		                        .withId(fieldId1)
		                        .atPosition(400, 100)
		                        .onPage(0)
		                        .build())
		                    .withField(FieldBuilder.textField()
		                        .withId(fieldId2)
		                        .atPosition(400, 200)
		                        .onPage(0)
		                        .build())
		                )
		            )
		            .withCondition(conditionRadio1)
		            .withCondition(conditionRadio2)
		            .withCondition(conditionRadio3)
		            .build();
		 		PackageId packageId = eslClient.createPackageOneStep(superDuperPackage);
		 		
		    }
	
	}